#include <iostream>
#include <vector>
#include <ext/pb_ds/assoc_container.hpp>
using namespace std;
using namespace __gnu_pbds;


struct node {
    pair<int, int> mx;
    long long sum;
    int op;

    node operator+(node o){
        return {max(mx, o.mx), sum + o.sum, -1};
    }
};

struct segment_tree {
    int n;
    vector<node> seg;

    segment_tree(int n1, vector<int> a){
        n = 1u << (unsigned)__lg(2 * n1 - 1);
        seg = vector<node>(2 * n - 1, node{{-1, -1}, 0, -1});
        for (int i = 0; i < n1; i ++) seg[i + n - 1] = {{a[i], i}, a[i], -1};
        for (int i = n - 2; i >= 0; i --) seg[i] = seg[2 * i + 1] + seg[2 * i + 2];
    }

    void propagate(int i, int lx, int rx){
        if (seg[i].op == -1) return;
        seg[2 * i + 1] = {{seg[i].op, lx}, (rx - lx + 1ll) * seg[i].op / 2, seg[i].op};
        seg[2 * i + 2] = {{seg[i].op, rx}, (rx - lx + 1ll) * seg[i].op / 2, seg[i].op};
        seg[i].op = -1;
    }

    void assign1(int i, int v, int l, int r, int lx, int rx){
        if (r < lx or rx < l) return;
        if (l <= lx and rx <= r){
            seg[i] = {{v, lx}, (rx - lx + 1ll) * v, v};
            return;
        }
        propagate(i, lx, rx);
        int m = (lx + rx) / 2;
        assign1(2 * i + 1, v, l, r, lx, m);
        assign1(2 * i + 2, v, l, r, m + 1, rx);
        seg[i] = seg[2 * i + 1] + seg[2 * i + 2];
    }

    node get1(int i, int l, int r, int lx, int rx){
        if (r < lx or rx < l) return {{-1, -1}, 0, -1};
        if (l <= lx and rx <= r) return seg[i];
        propagate(i, lx, rx);
        int m = (lx + rx) / 2;
        return get1(2 * i + 1, l, r, lx, m) + get1(2 * i + 2, l, r, m + 1, rx);
    }

    void assign(int v, int l, int r){
        if (l > r) return;
        assign1(0, v, l, r, 0, n - 1);
    }

    node get(int l, int r){
        return get1(0, l, r, 0, n - 1);
    }
};


int main(){
    ios_base :: sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    int n;
    cin >> n;
    vector<int> a(n);
    for (auto& i: a) cin >> i;
    vector<int> lt(n, -1), rt(n, n);
    vector<int> stack;
    for (int i = 0; i < n; i ++){
        while (not stack.empty() and a[i] > a[stack.back()]){
            rt[stack.back()] = i;
            stack.pop_back();
        }
        stack.push_back(i);
    }
    stack.clear();
    for (int i = n - 1; i >= 0; i --){
        while (not stack.empty() and a[i] > a[stack.back()]){
            lt[stack.back()] = i;
            stack.pop_back();
        }
        stack.push_back(i);
    }
    vector<long long> p(n + 1, 0);
    for (int i = 0; i < n; i ++) p[i + 1] = p[i] + a[i];
    tree<int, int, less<>, rb_tree_tag, tree_order_statistics_node_update> bnd;
    for (int i = 0; i < n; i ++) bnd.insert({i, i});
    segment_tree d(n, a), h(n, a);
    for (int i = 1; i < n; i ++){
        int kj;
        cin >> kj;
        auto itr = bnd.find_by_order(kj - 1);
        auto [l0, r0] = *itr;
        auto [l1, r1] = *++ itr;
        (-- itr) -> second = r1;
        bnd.erase(++ itr);
        auto [mx, j] = h.get(l1, r1).mx;
        if (lt[j] >= l0) d.assign(min(h.get(l0, lt[j]).mx.first, mx), lt[j] + 1, r0);
        else{
            pair<int, int> nd = h.get(l0, r0).mx;
            mx = nd.first, j = nd.second;
            d.assign(mx, j, r0);
        }
        pair<int, int> nd = h.get(l0, r0).mx;
        mx = nd.first, j = nd.second;
        if (rt[j] <= r1) d.assign(min(h.get(rt[j], r1).mx.first, mx), l1, rt[j] - 1);
        else{
            pair<int, int> nd = h.get(l1, r1).mx;
            mx = nd.first, j = nd.second;
            d.assign(mx, l1, j);
        }
        cout << d.get(l0, r1).sum - (p[r1 + 1] - p[l0])<< "\n";
    }
}
