#include <iostream>
#include <algorithm>
#include <math.h>
#include <random>
#include <map>
#include <set>
#include <vector>

using namespace std;

#define len(v) (int)((v).size())
typedef long long ll;

const int N = 1e5;

const int sz = 1 << 20;
const int NA = -1;
const int inf = 1e9;

struct obj {
	ll sum;
	int imx, mx, sec_mx;
	int mn_bl, mx_bl;

	obj() : sum(0), mx(NA), sec_mx(NA), imx(NA), mn_bl(inf), mx_bl(-inf) {};
};

obj merge(obj &a, obj &b) {
	obj res;
	res.sum = a.sum + b.sum;
	res.mx = max(a.mx, b.mx);
	if (res.mx == a.mx) res.imx = a.imx;
	else res.imx = b.imx;

	res.sec_mx = max(a.sec_mx, b.sec_mx);
	if (a.mx == res.mx && b.mx > res.sec_mx) res.sec_mx = b.mx;
	if (b.mx == res.mx && a.mx > res.sec_mx) res.sec_mx = a.mx;

	res.mx_bl = max(a.mx_bl, b.mx_bl);
	res.mn_bl = min(a.mn_bl, b.mn_bl);
	return res;
}

obj tree[sz];
int add[sz], bl_add[sz];

void build(int v, int l, int r, vector<int>& a) {
	add[v] = NA;
	bl_add[v] = 0;
	if (r - l == 1) {
		tree[v].mx = tree[v].sum = a[l];
		tree[v].mx_bl = tree[v].mn_bl = tree[v].imx = l;
		return;
	}
	int m = (l + r) / 2;
	build(v * 2, l, m, a);
	build(v * 2 + 1, m, r, a);
	tree[v] = merge(tree[v * 2], tree[v * 2 + 1]);
}

void push1(int v, int l, int r) {
	if (add[v] == NA) return;

	if (r - l > 1) {
		add[v * 2] = add[v];
		add[v * 2 + 1] = add[v];
	}
	tree[v].sum = add[v] * 1ll * (r - l);
	tree[v].mx = add[v];
	tree[v].imx = l;
	add[v] = NA;
	return;
}

void push2(int v, int ln) {
	if (bl_add[v] == 0) return;

	if (ln > 1) {
		bl_add[v * 2] += bl_add[v];
		bl_add[v * 2 + 1] += bl_add[v];
	}
	tree[v].mn_bl += bl_add[v];
	tree[v].mx_bl += bl_add[v];
	bl_add[v] = 0;
	return;
}

void push(int v, int l, int r) {
	push1(v, l, r);
	push2(v, r - l);
}

void upd1(int v, int l, int r, int ql, int qr, int qx) {
	push(v, l, r);
	if (l >= qr || ql >= r) return;
	if (l >= ql && r <= qr && r - l == 1) {
		if (tree[v].mx <= qx) {
			add[v] = qx;
			push(v, l, r);
		}
		return;
	}
	int m = (l + r) / 2;
	upd1(v * 2, l, m, ql, qr, qx);
	upd1(v * 2 + 1, m, r, ql, qr, qx);
	tree[v] = merge(tree[v * 2], tree[v * 2 + 1]);
}

void upd2(int v, int l, int r, int ql, int qr, int qx) {
	push(v, l, r);
	if (l >= qr || ql >= r) return;
	if (l >= ql && r <= qr) {
		bl_add[v] += qx;
		push(v, l, r);
		return;
	}
	int m = (l + r) / 2;
	upd2(v * 2, l, m, ql, qr, qx);
	upd2(v * 2 + 1, m, r, ql, qr, qx);
	tree[v] = merge(tree[v * 2], tree[v * 2 + 1]);
}


obj get(int v, int l, int r, int ql, int qr) {
	push(v, l, r);
	if (l >= qr || ql >= r) return obj();
	if (l >= ql && r <= qr) return tree[v];
	int m = (l + r) / 2;
	obj r1 = get(v * 2, l, m, ql, qr);
	obj r2 = get(v * 2 + 1, m, r, ql, qr);
	return merge(r1, r2);
}

int find_l(int v, int l, int r, int qx) {
	push(v, l, r);
	if (r - l == 1) return l;
	int m = (l + r) / 2;
	push(v * 2, l, m);
	if (tree[v * 2].mx_bl >= qx) return find_l(v * 2, l, m, qx);
	else return  find_l (v * 2 + 1, m, r, qx);
}

int find_r(int v, int l, int r, int qx) {
	push(v, l, r);
	if (r - l == 1) return l;
	int m = (l + r) / 2;
	push(v * 2 + 1, m, r);
	if (tree[v * 2 + 1].mn_bl <= qx) return find_r(v * 2 + 1, m, r, qx);
	else return  find_r(v * 2, l, m, qx);
}

ll pref[N];

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	int n;
	cin >> n;
	vector<int> h(n);
	for (int i = 0; i < n; ++i) {
		cin >> h[i];
	}
	for (int i = 0; i < n; ++i) {
		pref[i + 1] = pref[i] + h[i];
	}

	build(1, 0, n, h);

	for (int i = 0; i < n - 1; ++i) {
		int k1, k2;
		cin >> k2;
		k1 = k2 - 1;

		int l1 = find_l(1, 0, n, k1);
		int r1 = find_r(1, 0, n, k1);

		int l2 = find_l(1, 0, n, k2);
		int r2 = find_r(1, 0, n, k2);

		obj bl1 = get(1, 0, n, l1, r1 + 1);
		obj bl2 = get(1, 0, n, l2, r2 + 1);

		upd1(1, 0, n, bl1.imx, bl2.imx + 1, min(bl1.mx, bl2.mx));
		upd2(1, 0, n, l2, n, -1);

		cout << get(1, 0, n, l1, r2 + 1).sum - (pref[r2 + 1] - pref[l1]) << '\n';
	}

}
