#include <iostream>
#include <vector>
#include <numeric>
#include <set>
#include <map>

using namespace std;
using ll = long long;

void solve();

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr), cout.tie(nullptr);

    ll t = 1;
    // cin >> t;
    while (t--)
        solve();

    return 0;
}

class segment_tree_sum {
    ll n;
    vector<ll> t;

    void build(ll v, ll l, ll r, vector<ll> &a) {
        if (l + 1 == r) {
            t[v] = a[l];
            return;
        }
        ll m = (l + r) / 2;
        build(v * 2 + 1, l, m, a);
        build(v * 2 + 2, m, r, a);
        t[v] = t[v * 2 + 1] + t[v * 2 + 2];
    }

    void update(ll v, ll l, ll r, ll qi, ll qe) {
        if (r <= qi || qi < l) {
            return;
        }
        if (l + 1 == r) {
            t[v] = qe;
            return;
        }
        ll m = (l + r) / 2;
        update(v * 2 + 1, l, m, qi, qe);
        update(v * 2 + 2, m, r, qi, qe);
        t[v] = t[v * 2 + 1] + t[v * 2 + 2];
    }

    ll query(ll v, ll l, ll r, ll ql, ll qr) {
        if (r <= ql || qr <= l) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return t[v];
        }
        ll m = (l + r) / 2;
        return query(v * 2 + 1, l, m, ql, qr) + query(v * 2 + 2, m, r, ql, qr);
    }

public:
    segment_tree_sum() {}

    segment_tree_sum(ll n, ll e = 0) : n(n) {
        vector<ll> a(n, e);
        t.resize(n * 4);
        build(0, 0, n, a);
    }

    segment_tree_sum(ll n, vector<ll> &a) : n(n) {
        t.resize(n * 4);
        build(0, 0, n, a);
    }

    void update(ll qi, ll qe) { update(0, 0, n, qi, qe); }

    ll query(ll ql, ll qr) { return query(0, 0, n, ql, qr); }
};

class segment_tree_k {
    ll n;

    ll query(ll l, ll r, ll qe) {
        if (l + 1 == r) {
            return l;
        }
        ll m = (l + r) / 2;
        if (tree.query(l, m) >= qe) {
            return query(l, m, qe);
        }
        return query(m, r, qe - tree.query(l, m));
    }

public:
    segment_tree_sum tree;

    segment_tree_k(ll n) : n(n), tree(segment_tree_sum(n, 1)) {
    }

    segment_tree_k(ll n, vector<ll> &a) : n(n) {
        for (ll &e: a) {
            e = (e != 0);
        }
        tree = segment_tree_sum(n, a);
    }

    void update(ll qi, ll qe) {
        tree.update(qi, (qe != 0));
    }

    ll query(ll qe) {
        return query(0, n, qe);
    }
};

constexpr ll INF = 1e15;

class segment_tree_max {
    ll n;
    vector<ll> t;

    void build(ll v, ll l, ll r, vector<ll> &a) {
        if (l + 1 == r) {
            t[v] = a[l];
            return;
        }
        ll m = (l + r) / 2;
        build(v * 2 + 1, l, m, a);
        build(v * 2 + 2, m, r, a);
        t[v] = max(t[v * 2 + 1], t[v * 2 + 2]);
    }

    ll query(ll v, ll l, ll r, ll ql, ll qr) {
        if (r <= ql || qr <= l) {
            return -INF;
        }
        if (ql <= l && r <= qr) {
            return t[v];
        }
        ll m = (l + r) / 2;
        return max(query(v * 2 + 1, l, m, ql, qr), query(v * 2 + 2, m, r, ql, qr));
    }

public:
    segment_tree_max() {}

    segment_tree_max(ll n, ll e = 0) : n(n) {
        vector<ll> a(n, e);
        t.resize(n * 4);
        build(0, 0, n, a);
    }

    segment_tree_max(ll n, vector<ll> &a) : n(n) {
        t.resize(n * 4);
        build(0, 0, n, a);
    }

    ll query(ll ql, ll qr) {
        return query(0, 0, n, ql, qr);
    }
};

class segment_tree {
    ll n;
    vector<map<vector<ll>, ll>> t;
    segment_tree_max tree;

    map<vector<ll>, ll> merge(map<vector<ll>, ll> &el, map<vector<ll>, ll> &er, ll maxl, ll maxr) {
        map<vector<ll>, ll> ans;
        for (const auto& [k, v]: el) {
            ans[{k[0], k[1], max(k[2], maxr)}] += v;
        }
        for (const auto& [k, v]: er) {
            ans[{max(k[0], maxl), k[1], k[2]}] += v;
        }
        return ans;
    }

    ll build(ll v, ll l, ll r, vector<ll> &a) {
        if (l + 1 == r) {
            t[v][{a[l], a[l], a[l]}] = 1;
            return a[l];
        }
        ll m = (l + r) / 2;
        ll mxl = build(v * 2 + 1, l, m, a);
        ll mxr = build(v * 2 + 2, m, r, a);
        t[v] = merge(t[v * 2 + 1], t[v * 2 + 2], mxl, mxr);
        return max(mxl, mxr);
    }

    pair<ll, map<vector<ll>, ll>> query(ll v, ll l, ll r, ll ql, ll qr) {
        if (r <= ql || qr <= l) {
            return {-INF, {}};
        }
        if (ql <= l && r <= qr) {
            return {tree.query(l, r), t[v]};
        }
        ll m = (l + r) / 2;
        auto [mxl, al] = query(v * 2 + 1, l, m, ql, qr);
        auto [mxr, ar] = query(v * 2 + 2, m, r, ql, qr);
        return {max(mxl, mxr), merge(al, ar, mxl, mxr)};
    }

public:
    segment_tree(ll n, ll e = 0) : n(n) {
        vector<ll> a(n, e);
        t.resize(n * 4);
        tree = segment_tree_max(n, a);
        build(0, 0, n, a);
    }

    segment_tree(ll n, vector<ll> &a) : n(n) {
        t.resize(n * 4);
        tree = segment_tree_max(n, a);
        build(0, 0, n, a);
    }

    map<vector<ll>, ll> query(ll ql, ll qr) {
        return query(0, 0, n, ql, qr).second;
    }
};

void solve() {
    ll n;
    cin >> n;
    vector<ll> h(n);
    for (ll i = 0; i < n; i++) cin >> h[i];
    segment_tree_max tree_max(n, h);
    vector<ll> q(n - 1);
    for (ll i = 0; i < n - 1; i++) cin >> q[i];
    segment_tree_k tree(n);
    segment_tree_sum len(n, 1);
    segment_tree t(n, h);
    for (ll j: q) {
        ll i1 = tree.query(j);
        ll len1 = len.query(i1, i1 + 1);
        ll i2 = tree.query(j + 1);
        ll len2 = len.query(i2, i2 + 1);
        tree.update(i1, len1 + len2);
        tree.update(i2, 0);
        len.update(i1, len1 + len2);
        len.update(i2, 0);
        ll l = i1, r = i2 + len2;
//        cout << l << ' ' << r << '\n';
        ll ans = 0;
        auto res = t.query(l, r);
        for (const auto& [k, v]: res) {
            ans += (min(k[0], k[2]) - k[1]) * v;
        }
        cout << ans << '\n';
    }
}
/*
8
9 1 8 1 5 2 3 6
3 3 1 3 3 2 1

 */