#include <iostream>
#include <vector>
#include <functional>
#include <mutex>
#include <chrono>

std::mutex mutex = std::mutex();

void Loop(unsigned long long i, unsigned long long to, unsigned long long depth, std::function<void(std::vector<unsigned long long>&)>& func, std::vector<unsigned long long> args = {}, bool starter = true, unsigned max_depth = -1){
    if( starter ){
        args.resize(depth);
        max_depth = depth;
    }
    for(; i < to; ++i){
        if(depth == 1){
            args[max_depth - depth] = i;
            func(args);
        }
        else{
            args[max_depth - depth] = i;
            if( starter ){
                std::thread thread = std::thread([i, to, depth, &func, &args, max_depth](){ Loop(i + 1, to, depth - 1, func, args, false, max_depth); });
                thread.detach();
            }
            else{
                Loop(i + 1, to, depth - 1, func, args, false, max_depth);
            }
        }
    }
}

unsigned long long CountDif(std::vector<unsigned long long>& sums){
    unsigned long long max_sum = 0;
    unsigned long long min_sum = (unsigned long long)(-1);

    for(unsigned long long i = 0; i < sums.size(); ++i){
        max_sum = sums[i] * (sums[i] > max_sum) + max_sum * (max_sum >= sums[i]);
        min_sum = sums[i] * (sums[i] < min_sum) + min_sum * (min_sum <= sums[i]);
    }

    return max_sum - min_sum;
}

int main(){
    auto time_point = std::chrono::high_resolution_clock::now();

    unsigned long long n, k, max_dif = 0;

    scanf("%llu", &n);
    scanf("%llu", &k);

    std::vector<unsigned long long> values;
    values.resize(n);

    for(unsigned long long i = 0; i < n; ++i){
        scanf("%llu", &values[i]);
    }

    auto func = std::function<void(std::vector<unsigned long long>&)>([&values, &max_dif](std::vector<unsigned long long>& args){
            std::vector<unsigned long long> sums;
            sums.resize(args.size() + 1);
            for(unsigned long long i = 0; i < sums.size(); ++i){
                sums[i] = 0;
            }
            for(unsigned long long i = 0; i <= args[0]; ++i){
                sums[0] += values[i];
            }
            for(unsigned long long i = 1; i < args.size(); ++i){
                for(unsigned long long j = args[i - 1] + 1; j <= args[i]; ++j){
                    sums[i] += values[j];
                }
            }
            for(unsigned long long i = args[args.size() - 1] + 1; i < values.size(); ++i){
                sums[sums.size() - 1] += values[i];
            }

            unsigned long long dif = CountDif(sums);
            //printf("Args: %llu %llu  dif: %llu   sums: %llu %llu %llu\n", args[0], args[1], dif, sums[0], sums[1], sums[2]);
            //printf("Dif: %llu\n", dif);
            mutex.lock();
            max_dif = dif * (dif > max_dif) + max_dif * (max_dif >= dif);
            mutex.unlock();
            //printf("Max Dif: %llu\n", dif);
         });

    Loop(0, n - 1, k - 1, func);

    while( (std::chrono::high_resolution_clock::now() - time_point).count() / 100000 < 9970) {}

    printf("%llu\n", max_dif);
}
