#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>
#include <array>
#include <set>

#include <ext/pb_ds/tree_policy.hpp>

#pragma GCC optimize("Ofast,unroll-loops")
#pragma GCC target("avx2,tune=native")

using namespace std;
using namespace __gnu_pbds;

using ll = long long;
#define all(x) x.begin(), x.end()
#define ar array

struct Segtree {
    vector<pair<ll,ll>> st;
    vector<pair<ll,ll>> orig_st;
    vector<bool> is_revert;
    vector<ll> lazy;

    void push_up(int v, int l, int r) {
        if(l!=r){
            st[v].first = max(st[v*2].first, st[v*2+1].first);
            st[v].second = st[v*2].second+ st[v*2+1].second;
        }
    }

    void push_down(int v, int l, int r) {
        if(is_revert[v]){
//            lazy[v] = 0;

            st[v].first = orig_st[v].first + lazy[v];
            st[v].second = orig_st[v].second + lazy[v] * (r-l+1);
        } else {
            st[v].first +=lazy[v];
            st[v].second+= lazy[v] * (r-l+1);
        }

        if(l!=r) {
            if(is_revert[v]){
                lazy[v*2] = 0;
                lazy[v*2+1] = 0;
                is_revert[v*2] = true;
                is_revert[v*2+1] = true;
                int m= (r+l)/2;
                st[v*2] = orig_st[v*2];
                st[v*2].first += lazy[v];
                st[v*2].second += lazy[v]*(m-l+1);
                st[v*2+1] = orig_st[v*2+1];
                st[v*2+1].first += lazy[v];
                st[v*2+1].second += lazy[v]*(r-(m+1)+1);
            }

            lazy[v*2] += lazy[v];
            lazy[v*2+1] += lazy[v];


        }
        lazy[v] = 0;
        is_revert[v] = false;
    }

    void build(int v, int l, int r, const vector<ll> &arr) {
        if(l==r){
            st[v].first = arr[l];
            st[v].second = arr[l];
        } else {
            int m = (r+l)/2;
            build(v*2, l,m, arr);
            build(v*2+1, m+1,r, arr);
            push_up(v,l,r);
        }
    }

    Segtree(const vector<ll> &arr) {
        st.resize(4*arr.size());
        lazy.resize(4*arr.size());
        is_revert.resize(4*arr.size());
        build(1,0,arr.size()-1,arr);
        orig_st = st;
    }



    void update(int v, int l, int r, int ql, int qr, ll delt) {
        if(r < ql || qr < l) {
            return;
        }


        if(ql <=l && r <= qr) {

            lazy[v] += delt;
            push_down(v,l,r);

        } else {
            int m = (r+l)/2;
            update(v*2,l,m,ql,qr,delt);
            update(v*2+1,m+1,r,ql,qr,delt);
            push_up(v,l,r);
        }
    }

    void revert(int v, int l, int r, int ql, int qr) {
        if(r < ql || qr < l) {
            return;
        }
        if(ql <=l && r <= qr) {
            lazy[v] = 0;
            is_revert[v] = true;
            push_down(v,l,r);

//            cout << st[v].first << " " << st[v].second <<" " << orig_st[v].first << " " << orig_st[v].second<< endl;
        } else {
            int m = (r+l)/2;
            revert(v*2,l,m,ql,qr);
            revert(v*2+1,m+1,r,ql,qr);
            push_up(v,l,r);
        }
    }

    pair<ll,ll> query(int v, int l, int r, int ql, int qr) {
        if(r < ql || qr < l) {
            return {-1e18,0};
        }

        push_down(v,l,r);
        push_up(v,l,r);


        if(ql <=l && r <= qr) {
            return st[v];
        } else {
            int m = (r+l)/2;
            auto res1 = query(v*2,l,m,ql,qr);
            auto res2 = query(v*2+1,m+1,r,ql,qr);
            return {max(res1.first, res2.first), res1.second + res2.second};
        }
    }


    void range_add(int l, int r, ll delt) {
        if(l > r) {
            return;
        }
        update(1,0,st.size()/4-1,l,r,delt);
    }

    pair<ll,ll> query(int l, int r) {
        if(l > r) {
            return {0,0};
        }
        return  query(1,0,st.size()/4-1,l,r);
    }

    void range_revert(int l, int r) {
        if(l >r) {
            return;
        }

        revert(1,0,st.size()/4-1, l,r);
    }

};

void solve() {
    int n;
    cin >> n;
    vector<ll> arr(n);
    for (int i = 0; i <n; ++i) {
        cin >> arr[i];
    }

    vector<ll> squik(n);
    for (int i = 0; i < n; ++i) {
        squik[i] = arr[i] * -1;
    }



    Segtree tree_ans(squik);


    for (int i = 0; i < n; ++i) {
        tree_ans.range_add(i,i,squik[i]*-1);
    }




    Segtree tree(arr);



    vector<ll> blockss(n);
    for (int j = 0; j <n; ++j) {
        blockss[j] = j;
    }
    Segtree blocks(blockss);



    int nn = n;
    while (--nn) {
        int k;
        cin >> k;
        k--;

        int left_one = 0, right_one = 0, left_two = 0, right_two = 0;


        {
            int l = 0, r = n - 1;

            while (r - l > 1) {
                int m = (r + l) / 2;
                if (blocks.query(0, m).first < k) {
                    l = m+1;
                } else {
                    r = m;
                }
            }

            if (blocks.query(0, l).first == k) {
                left_one = l;
            } else {
                left_one = r;
            }



        }

        {
            int l = left_one, r = n - 1;
            while (r - l > 1) {
                int m = (r + l) / 2;
                if (blocks.query(left_one, m).first > k) {
                    r = m - 1;
                } else {
                    l = m;
                }
            }

            if (blocks.query(left_one, r).first == k) {
                right_one = r;
            } else {
                right_one = l;
            }
        }


        left_two = right_one+1;

        {
            int l = left_two, r = n - 1;
            while (r - l > 1) {
                int m = (r + l) / 2;
                if (blocks.query(left_two, m).first == (k + 1)) {
                    l = m;

                } else {
                    r = m - 1;
                }
            }

            if (blocks.query(left_two, r).first == (k + 1)) {
                right_two = r;
            } else {
                right_two = l;
            }
        }






        blocks.range_add(left_two, n - 1, -1);



        ll right_block_max = tree.query(left_two, right_two).first;
        ll left_block_max = tree.query(left_one, right_one).first;

//        cout <<left_block_max << " "<< right_block_max << endl;

        int partition1 = right_one+1;
        {
            int l = left_one, r = right_one;
            while (r-l>1) {
                int m = (r+l)/2;
                if(tree.query(left_one, m).first >= right_block_max && tree.query( m,right_one).first <= right_block_max) {
                    r = m;
                } else {
                    l = m+1;
                }
            }




            if(tree.query(left_one, l).first >= right_block_max && tree.query( l,right_one).first <= right_block_max) {
                partition1 = l;
            } else if (tree.query(left_one, r).first >= right_block_max && tree.query(r,right_one).first <= right_block_max) {
                partition1 = r;
            }
        }

        tree_ans.range_revert(partition1, right_one);
        tree_ans.range_add(partition1, right_one, right_block_max);




        int partition2 = left_two-1;
        {
            int l = left_two, r = right_two;
            while (r-l>1) {
                int m = (r+l)/2;
                if(tree.query(left_two, m).first <= left_block_max && tree.query( m,right_two).first >= left_block_max) {
                    l = m;

                } else {
                    r = m-1;
                }
            }


            if(tree.query(left_two, r).first <= left_block_max && tree.query( r,right_two).first >= left_block_max) {
                partition2 = r;
            } else if (tree.query(left_two, l).first <= left_block_max && tree.query( l,right_two).first >= left_block_max) {
                partition2 = l;
            }
        }




        tree_ans.range_revert(left_two, partition2);
        tree_ans.range_add(left_two, partition2,left_block_max);

////        cout << left_one << " " << right_two << endl;
////        for (int i = 0; i < n; ++i) {
////            cout << tree_ans.query(i,i).first << ", ";
////        }
////        cout<<endl;
////
//////        cout << left_one << " " << right_two << endl;
//        for (int i = 0; i < n; ++i) {
//            cout << blocks.query(i,i).first << ", ";
//        }
//        cout<<endl;

        cout << tree_ans.query(left_one, right_two).second << '\n';
    }
}

int main() {
    iostream::sync_with_stdio(false);
    cout.tie(0);
    cin.tie(0);


    int t;
//    cin >> t;
    t = 1;
    while (t--) {
        solve();
    }
}
