#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>

using namespace std;
using ll = long long;

struct SGT {
    vector<ll> t;

    SGT(int n) : t(n * 4) {
        build(0, 0, n);
    }

    void build(int v, int l, int r) {
        if (l + 1 == r) {
            t[v] = 1;
            return;
        }
        int mid = (l + r) / 2;
        build(2 * v + 1, l, mid), build(2 * v + 2, mid, r);
        t[v] = t[2 * v + 1] + t[2 * v + 2];
    }

    void del(int v, int l, int r, int i) {
        if (l > i || r <= i) return;
        if (l + 1 == r) {
            t[v] = 0;
            return;
        }
        int mid = (l + r) / 2;
        del(2 * v + 1, l, mid, i), del(2 * v + 2, mid, r, i);
        t[v] = t[2 * v + 1] + t[2 * v + 2];
    }

    int fnd(int v, int l, int r, int k) {
        if (l + 1 == r) {
            return l;
        }
        int mid = (l + r) / 2;
        if (t[2 * v + 1] >= k) {
            return fnd(2 * v + 1, l, mid, k);
        }
        return fnd(2 * v + 2, mid, r, k - t[2 * v + 1]);
    }
};

struct DSU {
    vector<ll> h;
    vector<int> p, l, r, sz;
    vector<ll> mxInd, premx, postmx, sum;

    DSU(int n, vector<ll> &h) : h(h), p(n), mxInd(n), premx(n), postmx(n), sum(n), l(n), r(n), sz(n, 1) {
        iota(p.begin(), p.end(), 0);
        for (int i = 0; i < n; ++i) {
            mxInd[i] = i;
            premx[i] = 0;
            postmx[i] = 0;
            sum[i] = h[i];
            l[i] = i;
            r[i] = i + 1;
        }
    }

    int par(int x) {
        if (p[x] != p[p[x]]) p[x] = par(p[p[x]]);
        return p[x];
    }

    void mrg(int x, int y) {
        x = par(x);
        y = par(y);
        if (x == y) return;
        if (sz[x] < sz[y]) swap(x, y);
        sz[x] += sz[y];
        p[y] = x;
        l[x] = min(l[x], l[y]);
        r[x] = max(r[x], r[y]);
        sum[x] += sum[y];
        if (x < y) {
            if (h[mxInd[x]] >= h[mxInd[y]]) {
                //mxInd[x] = mxInd[x]
            } else {

                mxInd[x] = mxInd[y];
            }
        } else {
            if (h[mxInd[x]] > h[mxInd[y]]) {

                //mxInd[x] = mxInd[x]
            } else {

                mxInd[x] = mxInd[y];
            }
        }
        premx[x] = postmx[x] = 0;
        ll tmp = 0;
        for (int i = l[x]; i < mxInd[x]; ++i) {
            tmp = max(tmp, h[i]);
            premx[x] += tmp;
        }
        tmp = 0;
        for (int i = r[x] - 1; i > mxInd[x]; --i) {
            tmp = max(tmp, h[i]);
            postmx[x] += tmp;
        }

        if (ans(x) < 0) {
            cout << "WTF\n";
        }
    }

    ll ans(int x) {
        x = par(x);
        return premx[x] + h[mxInd[x]] + postmx[x] - sum[x];
    }
};
/*
 8
9 1 8 1 5 2 3 6
3 3 1 3 3 2 1
 */
void solve() {
    int n;
    cin >> n;
    vector<ll> h(n);
    for (int i = 0; i < n; ++i) cin >> h[i];

    SGT t(n);
    DSU ss(n, h);
    for (int _q = 0, kj, kj1; _q < n - 1; ++_q) {
        cin >> kj;
        --kj;
        kj1 = kj + 1;
        kj = t.fnd(0, 0, n, kj + 1);
        kj1 = t.fnd(0, 0, n, kj1 + 1);
        ss.mrg(kj, kj1);
        cout << ss.ans(kj) << '\n';


        t.del(0, 0, n, kj1);
    }
}

/*
8
9 1 8 1 5 2 3 6
3 3 1 3 3 2 1
 */
int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    solve();
}
