#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>
#include <deque>

using namespace std;
using ll = long long;

struct SGT {
    vector<ll> t;

    SGT(int n) : t(n * 4) {
        build(0, 0, n);
    }

    void build(int v, int l, int r) {
        if (l + 1 == r) {
            t[v] = 1;
            return;
        }
        int mid = (l + r) / 2;
        build(2 * v + 1, l, mid), build(2 * v + 2, mid, r);
        t[v] = t[2 * v + 1] + t[2 * v + 2];
    }

    void del(int v, int l, int r, int i) {
        if (l > i || r <= i) return;
        if (l + 1 == r) {
            t[v] = 0;
            return;
        }
        int mid = (l + r) / 2;
        del(2 * v + 1, l, mid, i), del(2 * v + 2, mid, r, i);
        t[v] = t[2 * v + 1] + t[2 * v + 2];
    }

    int fnd(int v, int l, int r, int k) {
        if (l + 1 == r) {
            return l;
        }
        int mid = (l + r) / 2;
        if (t[2 * v + 1] >= k) {
            return fnd(2 * v + 1, l, mid, k);
        }
        return fnd(2 * v + 2, mid, r, k - t[2 * v + 1]);
    }
};

struct DSU {
    vector<ll> h;
    vector<int> p, l, r, sz;
    vector<ll> mxInd, sum, sumsmart;
    vector<deque<ll>> premx, postmx, precnt, postcnt;

    DSU(int n, vector<ll> &h) : h(h), p(n), mxInd(n), sum(n), l(n), r(n), sz(n, 1), premx(n), postmx(n), precnt(n), postcnt(n), sumsmart(n) {
        iota(p.begin(), p.end(), 0);
        for (int i = 0; i < n; ++i) {
            mxInd[i] = i;
            sum[i] = h[i];
            l[i] = i;
            r[i] = i + 1;
        }
    }

    int par(int x) {
        if (p[x] != p[p[x]]) p[x] = par(p[p[x]]);
        return p[x];
    }

    void mrg(int x, int y) {
        x = par(x);
        y = par(y);
        if (x == y) return;
        if (sz[x] < sz[y]) swap(x, y);
        sz[x] += sz[y];
        p[y] = x;

        sum[x] += sum[y];
        if (x < y) {
            if (h[mxInd[x]] >= h[mxInd[y]]) {
                //mxInd[x] = mxInd[x]
                int cnt = 0;
                ll mx = h[mxInd[y]];
                while (!postmx[x].empty()) {
                    if (postmx[x].back() > mx) break;
                    cnt += postcnt[x].back();
                    sumsmart[x] -= postmx[x].back() * postcnt[x].back();
                    postmx[x].pop_back();
                    postcnt[x].pop_back();
                }
                postmx[x].push_back(mx);
                postcnt[x].push_back(cnt);
                sumsmart[x] += premx[x].back() * precnt[x].back();

            } else {
                ll mx = mxInd[x];
                premx[x].push_back(h[mxInd[x]]);
                precnt[x].push_back(r[x] - mxInd[x]);
                sumsmart[x] += h[mxInd[x]] * (r[x] - mxInd[x]);
                for (int i = 0; i < premx[y].size(); ++i) {
                    premx[x].push_back(max(mx, premx[y][i]));
                    precnt[x].push_back(precnt[y][i]);
                    sumsmart[x] += premx[x].back() * precnt[x].back();
                }

                for (int i = 0; i < postmx[x].size(); ++i) {
                    sumsmart[x] -= postmx[x][i] * postcnt[x][i];
                }
                postmx[x] = postmx[y];
                postcnt[x] = postcnt[y];
                for (int i = 0; i < postmx[x].size(); ++i) {
                    sumsmart[x] += postmx[x][i] * postcnt[x][i];
                }

                mxInd[x] = mxInd[y];
            }
        } else {
            if (h[mxInd[x]] > h[mxInd[y]]) {
                //mxInd[x] = mxInd[x]
                int cnt = 0;
                ll mx = h[mxInd[y]];
                while (!premx[x].empty()) {
                    if (premx[x].front() >= mx) break;
                    cnt += precnt[x].front();
                    sumsmart[x] -= premx[x].front() * precnt[x].front();
                    premx[x].pop_front();
                    precnt[x].pop_front();
                }
                premx[x].push_front(mx);
                premx[x].push_front(cnt);
                sumsmart[x] += premx[x].front() * precnt[x].front();

                mx = 0;
                vector<ll> tmp;
                for (int i = l[y]; i < r[y]; ++i) {
                    mx = max(mx, h[i]);
                    tmp.push_back(mx);
                }
                for (int i = int(tmp.size()) - 1; i >= 0; --i) {
                    premx[x].push_front(tmp[i]);
                    precnt[x].push_front(1);
                    sumsmart[x] += premx[x].front() * precnt[x].front();
                }
            } else {
                for (int i = 0; i < premx[x].size(); ++i) {
                    sumsmart[x] -= premx[x][i] * precnt[x][i];
                }
                premx[x] = premx[y];
                precnt[x] = precnt[y];
                for (int i = 0; i < premx[x].size(); ++i) {
                    sumsmart[x] += premx[x][i] * precnt[x][i];
                }

                postmx[x].push_back(h[mxInd[x]]);
                postcnt[x].push_back(mxInd[x] - l[x] + 1);
                sumsmart[x] += postmx[x].back() * postcnt[x].back();
                ll mx = h[mxInd[x]];
                for (int i = r[y] - 1; i > mxInd[y]; --i) {
                    mx = max(mx, h[i]);
                    postmx[x].push_back(mx);
                    postcnt[x].push_back(1);
                    sumsmart[x] += mx;
                }

                mxInd[x] = mxInd[y];
            }
        }
        l[x] = min(l[x], l[y]);
        r[x] = max(r[x], r[y]);

    }

    ll ans(int x) {
        x = par(x);
        return h[mxInd[x]] - sumsmart[x] - sum[x];
    }
};
/*
 8
9 1 8 1 5 2 3 6
3 3 1 3 3 2 1
 */
void solve() {
    int n;
    cin >> n;
    vector<ll> h(n);
    for (int i = 0; i < n; ++i) cin >> h[i];

    SGT t(n);
    DSU ss(n, h);
    for (int _q = 0, kj, kj1; _q < n - 1; ++_q) {
        cin >> kj;
        --kj;
        kj1 = kj + 1;
        kj = t.fnd(0, 0, n, kj + 1);
        kj1 = t.fnd(0, 0, n, kj1 + 1);
        ss.mrg(kj, kj1);
        cout << ss.ans(kj) << '\n';


        t.del(0, 0, n, kj1);
    }
}

/*
8
9 1 8 1 5 2 3 6
3 3 1 3 3 2 1
 */
int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    solve();
}
