#include <iostream>
#include <cmath>
#include <vector>
#include <algorithm>
#include <set>;

using namespace std;
using ll = long long;
using pll = pair<ll, ll>;
const ll inf = 1e18;
const int N = 2e6 + 3;
const int mod = 1e9 + 7;

ll normalize(ll x) {
    x %= mod;
    if (x < 0) x += mod;
    if (x >= mod) x -= mod;
    return x;
}

struct mint {
    ll vl;

    mint() : vl() {};
    mint(ll vl) : vl(normalize(vl)) {}

    friend mint operator+(mint a, mint b) {
        return {a.vl + b.vl};
    }
    friend mint operator-(mint a, mint b) {
        return {a.vl - b.vl};
    }
    friend mint operator*(mint a, mint b) {
        return {a.vl * b.vl};
    }
};

vector<mint> f(N), rf(N), r(N);

void init() {
    f[0] = f[1] = 1;
    rf[0] = rf[1] = 1;
    r[1] = 1;

    for (int i = 2; i < N; ++i) {
        f[i] = i * f[i - 1];
        r[i] = -1 * r[mod % i] * mint(mod / i);
        rf[i] = rf[i - 1] * r[i];
    }
}

mint cnk(ll n, ll k) {
    if (k < 0 || k > n) return 0;
    return f[n] * rf[k] * rf[n - k];
}


void solve() {
    init();
    int n, m, k;
    cin >> n >> m >> k;
    --n, --m;
    vector<int> x(k), y(k);
    for (int i = 0; i < k; ++i) {
        cin >> x[i] >> y[i];
        --x[i], --y[i];
    }

    vector<int> st(n + m);
    mint ans = 0;
    for (int i = m; i < n + m; ++i) st[i] = 1;
    do {
        vector<int> fin(n + m);
        for (int i = m; i < n + m; ++i) fin[i] = 1;

        do {
            vector<int> pst(n + m + 1), pfin(n + m + 1);
            for (int i = 0; i < n + m; ++i) pst[i + 1] = pst[i] + st[i];
            for (int i = 0; i < n + m; ++i) pfin[i + 1] = pfin[i] + fin[i];
            bool ok = true;
            for (int i = 1; i < n + m; ++i) {
                if (pfin[i] == pst[i]) {
                    ok = false;
                    break;
                }
            }
            if (!ok) continue;
            for (int i = 0; i < k; ++i) {
                if (pst[x[i] + y[i]] != x[i] && pfin[x[i] + y[i]] != x[i]) {
                    ok = false;
                    break;
                }
            }
            ans = ans + ok;
        } while (next_permutation(fin.begin(), fin.end()));

    } while (next_permutation(st.begin(), st.end()));
    cout << ans.vl << '\n';
}


int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    solve();
}

