#include <algorithm>
#include <iostream>
#include <vector>

using namespace std;

using ll = long long;

int n, k;
vector<ll> a;

struct Node {
    int i;
    ll Max;
    ll push;

    Node() {
        i = -1;
        Max = 0;
        push = 0;
    }

    Node(int _i, int _Max, int _push) {
        i = _i;
        Max = _Max;
        push = _push;
    }
};

class SegmentTree {
 private:
    int n;
    vector<ll> a;
    vector<Node> tree;

    inline Node Merge(Node& A, Node& B) {
        if (A.Max > B.Max) {
            return Node(A.i, A.Max, 0);
        } else {
            return Node(B.i, B.Max, 0);
        }
    }

    void Push(int p) {
        if (tree[p].push == 0) {
            return;
        }

        tree[2 * p].Max += tree[p].push;
        tree[2 * p].push += tree[p].push;

        tree[2 * p + 1].Max += tree[p].push;
        tree[2 * p + 1].push += tree[p].push;

        tree[p].push = 0;
    }

    void build(int p, int L, int R) {
        if (L == R) {
            tree[p] = Node(L, a[L], 0);
        } else {
            int M = (L + R) / 2;
            build(2 * p, L, M);
            build(2 * p + 1, M + 1, R);
            tree[p] = Merge(tree[2 * p], tree[2 * p + 1]);
        }
    }

    Node get(int p, int L, int R, int i, int j) {
        if (j < L || R < i) {
            return Node();
        } else if (i <= L && R <= j) {
            return tree[p];
        } else {
            Push(p);
            int M = (L + R) / 2;
            Node A = get(2 * p, L, M, i, j);
            Node B = get(2 * p + 1, M + 1, R, i, j);
            return Merge(A, B);
        }
    }

    void update(int p, int L, int R, int i, int j, ll add) {
        if (j < L || R < i) {
            return;
        } else if (i <= L && R <= j) {
            //Push(p);
            tree[p].Max += add;
            tree[p].push += add;
        } else {
            Push(p);
            int M = (L + R) / 2;
            update(2 * p, L, M, i, j, add);
            update(2 * p + 1, M + 1, R, i, j, add);
            tree[p] = Merge(tree[2 * p], tree[2 * p + 1]);
        }
    }

    void print(int p, int L, int R) {
        cout << p << ' ' << tree[p].i << ' ' << tree[p].Max << ' ' << tree[p].push << endl;
        if (R > L) {
            int M = (L + R) / 2;
            print(2 * p, L, M);
            print(2 * p + 1, M + 1, R);
        }
    }

 public:
    SegmentTree(int _n, vector<ll> _a) {
        n = _n;
        a.assign(n, 0);
        for (int i = 0; i < n; ++i) {
            a[i] = _a[i];
        }
        tree.assign(4 * n, Node());
        build(1, 0, n - 1);
    }

    ll get(int i, int j) {
        if (i > j) {
            return 0;
        }
        Node ans = get(1, 0, n - 1, i, j);
        return ans.Max;
    }

    void update(int i, int j, int add) {
        if (i > j) {
            return;
        }
        update(1, 0, n - 1, i, j, add);
    }

    void print() {
        print(1, 0, n - 1);
    }
};

ll solve_corr() {
    vector<ll> pref(n + 1);
    for (int i = 0; i < n; ++i) {
        pref[i + 1] = pref[i] + a[i];
    }

    if (k == 2) {
        ll ans = 0;
        for (int i = 1; i < n; ++i) {
            ans = max(ans, abs(2 * pref[i] - pref[n]));
        }
        return ans;
    }

    vector<ll> cnt(n), U(n);
    for (int i = 0; i < n; ++i) {
        cnt[i] = pref[min(n, i + n - k + 1)] - pref[i];
        U[i] = cnt[i];
    }
    ll ans = 0;
    for (int i = 0; i < n; ++i) {
        cnt[i] -= U[i];
        /*for (auto x : cnt) {
            cout << x << ' ' ;
        }
        cout << endl;*/
        ll Max = 0;
        for (int j = 0; j < i; ++j) {
            Max = max(Max, cnt[j]);
        }
        for (int j = i + 1; j < n; ++j) {
            Max = max(Max, cnt[j]);
        }
        ans = max(ans, Max - a[i]);
        //cout << i << ' ' << Max << endl;

        for (int j = max(0, i + k - n); j <= i; ++j) {
            cnt[j] += a[i];
        }
    }

    return ans;
}

ll solve() {
    vector<ll> pref(n + 1);
    for (int i = 0; i < n; ++i) {
        pref[i + 1] = pref[i] + a[i];
    }

    if (k == 2) {
        ll ans = 0;
        for (int i = 1; i < n; ++i) {
            ans = max(ans, abs(2 * pref[i] - pref[n]));
        }
        return ans;
    }

    vector<ll> U(n);
    for (int i = 0; i < n; ++i) {
        U[i] = pref[min(n, i + n - k + 1)] - pref[i];
    }
    SegmentTree cnt(n, U);
        /*for (int i = 0; i < n; ++i) {
            cout << cnt.get(i, i) << ' ';
        }
        cout << endl << endl;*/
    ll ans = 0;
    for (int i = 0; i < n; ++i) {
        cnt.update(i, i, -U[i]);
        /*for (auto x : cnt) {
            cout << x << ' ' ;
        }
        cout << endl;*/
        ll Max = max(cnt.get(0, i - 1), cnt.get(i + 1, n - 1));
        ans = max(ans, Max - a[i]);
        /*cout <<i << ' ' << Max <<' ' << cnt.get(0, i - 1) << " "<< cnt.get(i + 1, n - 1) << endl;
        for (int i = 0; i < n; ++i) {
            cout << cnt.get(i, i) << ' ';
        }
        cout << endl << endl;*/
        for (int j = max(0, i + k - n); j <= i; ++j) {
            cnt.update(j, j, a[i]);
        }
        //cnt.update(max(0, i + k - n), i, a[i]);
    }

    return ans;
}

void gen() {
    n = 10;
    k = 6;
    while (true) {
        a.assign(n, 0);
        for (int i = 0; i < n; ++i) {
            a[i] = rand() % 10;
        }
        if (solve() != solve_corr()) {
            cout << n << ' ' << k << endl;
            for (int i = 0; i < n; ++i) {
                cout << a[i] << ' ';
            }
            cout << endl;
            cout << solve() << endl;
            cout << solve_corr() << endl;
            return;
        }
        cout << "ok" << endl;
    }
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr), cin.precision(30);
    cout.tie(nullptr), cout.precision(30);

   cin >> n >> k;
    a.assign(n, 0);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
    }

    cout << solve() << endl;

 /*   SegmentTree ST(5, {12, 11, 13, 9, 9});
    ST.print();
    ST.update(0, 0, -12);
    ST.print();*/
    //gen();

    return 0;
}
