﻿#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <set>
#include <string>
#include <algorithm>
#include <cmath>
#include <iomanip>

using namespace std;

#define int long long

struct Segtree {

	int n;
	vector<int> tree;
	vector<int> to_push;

	Segtree(int _n) {
		n = _n;
		tree.resize(4 * n + 10);
		to_push.resize(4 * n + 10, -1);
	}

	void push(int v, int l, int r) {
		if (to_push[v] == -1) {
			return;
		}
		to_push[2 * v + 1] = to_push[v];
		to_push[2 * v + 2] = to_push[v];
		int m = (l + r) / 2;
		tree[2 * v + 1] = (m - l) * to_push[v];
		tree[2 * v + 2] = (r - m) * to_push[v];
		to_push[v] = -1;
	}

	void set(int v, int l, int r, int ql, int qr, int x) {
		if (l >= ql && r <= qr) {
			to_push[v] = x;
			tree[v] = (r - l) * x;
			return;
		}
		if (l >= qr || r <= ql) {
			return;
		}
		push(v, l, r);
		int m = (l + r) / 2;

		set(2 * v + 1, l, m, ql, qr, x);
		set(2 * v + 2, m, r, ql, qr, x);

		tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
	}

	int get(int v, int l, int r, int ql, int qr) {
		if (l >= ql && r <= qr) {
			return tree[v];
		}
		if (l >= qr || r <= ql) {
			return 0;
		}
		push(v, l, r);
		int m = (l + r) / 2;
		return get(2 * v + 1, l, m, ql, qr) + get(2 * v + 2, m, r, ql, qr);
	}

};


struct Segtree2 {

	int n;
	vector<int> tree_min, tree_max;
	vector<int> to_push;

	Segtree2(int _n) {
		n = _n;
		tree_min.resize(4 * n + 10);
		tree_max.resize(4 * n + 10);
		to_push.resize(4 * n + 10);
	}

	void push(int v, int l, int r) {
		if (to_push[v] == 0) {
			return;
		}
		to_push[2 * v + 1] += to_push[v];
		to_push[2 * v + 2] += to_push[v];
		tree_min[2 * v + 1] += to_push[v];
		tree_min[2 * v + 2] += to_push[v];
		tree_max[2 * v + 1] += to_push[v];
		tree_max[2 * v + 2] += to_push[v];
		to_push[v] = 0;
	}

	void add(int v, int l, int r, int ql, int qr, int x) {
		if (l >= ql && r <= qr) {
			to_push[v] += x;
			tree_min[v] += x;
			tree_max[v] += x;
			return;
		}
		if (l >= qr || r <= ql) {
			return;
		}
		push(v, l, r);
		int m = (l + r) / 2;
		add(2 * v + 1, l, m, ql, qr, x);
		add(2 * v + 2, m, r, ql, qr, x);
		tree_min[v] = min(tree_min[2 * v + 1], tree_min[2 * v + 2]);
		tree_max[v] = max(tree_max[2 * v + 1], tree_max[2 * v + 2]);
	}

	int go_down(int v, int l, int r, int x) {
		if (r - l == 1) {
			return l;
		}
		push(v, l, r);
		int m = (l + r) / 2;
		if (tree_max[2 * v + 1] >= x) {
			return go_down(2 * v + 1, l, m, x);
		}
		else {
			return go_down(2 * v + 2, m, r, x);
		}
	}

	void print(int v, int l, int r){
		if (r - l == 1) {
			cout << tree_min[v] << " ";
			return;
		}
		push(v, l, r);
		int m = (l + r) / 2;
		print(2 * v + 1, l, m);
		print(2 * v + 2, m, r);
	}
	
};

struct DSU {

	int n;
	vector<int> p;
	vector<int> h;
	vector<int> max_h;
	vector<int> pos;
	vector<int> val;

	DSU(int _n, vector<int> _max_h) {
		n = _n;
		p.resize(n);
		pos.resize(n);
		val.resize(n);
		for (int i = 0; i < n;i++) {
			p[i] = i;
			pos[i] = i;
		}
		h.resize(n);
		max_h = _max_h;
	}

	int get(int v) {
		while (v != p[v]) {
			v = p[v];
		}
		return v;
	}

	void unite(int v, int u) {
		v = get(v);
		u = get(u);
		if (h[u] > h[v]) {
			swap(u, v);
		}
		p[u] = v;
		if (h[u] == h[v]) {
			h[v]++;
		}
		if (max_h[u] > max_h[v]) {
			max_h[v] = max_h[u];
			pos[v] = pos[u];
		}
	}

};

signed main()
{
#ifdef LOCAL
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif

	int n;
	cin >> n;

	vector<int> a(n, 0);

	for (int i = 0; i < n;i++) {
		cin >> a[i];
	}

	Segtree tree(n);
	Segtree2 pos_tree(n);

	for (int i = 0; i < n;i++) {
		tree.set(0, 0, n, i, i + 1, a[i]);
		pos_tree.add(0, 0, n, i, i + 1, i);
	}

	int q = n - 1;

	DSU dsu(n, a);

	while (q--) {
		int x;
		cin >> x;
		x--;
		int l = pos_tree.go_down(0, 0, n, x);
		int r = pos_tree.go_down(0, 0, n, x + 1);
		int bl = l;
		int br = r;
		//cout << l << " " << r << endl;
		//pos_tree.print(0, 0, n);
		//cout << endl;
		pos_tree.add(0, 0, n, r, n, -1);
		/*l = dsu.get(l);
		r = dsu.get(r);
		int posl = dsu.pos[l];
		int posr = dsu.pos[r];
		int ans = dsu.val[l] + dsu.val[r];
		if (dsu.max_h[l] <= dsu.max_h[r]) {
			int binary_l = br - 1;
			int binary_r = posr;
			while (binary_r - binary_l > 1) {
				int mid = (binary_l + binary_r) / 2;
				if (tree.get(0, 0, n, mid, mid + 1) >= dsu.max_h[l]) {
					binary_r = mid;
				}
				else {
					binary_l = mid;
				}
			}
			ans -= tree.get(0, 0, n, posl, binary_r);
			tree.set(0, 0, n, posl, binary_r, dsu.max_h[l]);
			ans += dsu.max_h[l] * (binary_r - posl);
		}
		else {
			int binary_l = posl;
			int binary_r = br;
			while (binary_r - binary_l > 1) {
				int mid = (l + r) / 2;
				if (tree.get(0, 0, n, mid, mid + 1) >= dsu.max_h[r]) {
					binary_l = mid;
				}
				else {
					binary_r = mid;
				}
			}
			if (posr - binary_l - 1 > 0) {
				ans -= tree.get(0, 0, n, binary_r, posr);
				tree.set(0, 0, n, binary_r, posr, dsu.max_h[r]);
				ans += dsu.max_h[r] * (posr - binary_r);
			}
		}
		dsu.unite(l, r);
		dsu.val[dsu.get(l)] = ans;
		cout << ans << endl;*/
	}

}

