#include <iostream>
#include <algorithm>
#include <vector>


using namespace std;

using str = string;
using ll = long long;


struct node_mx {
	int mx, ind;

	node_mx() : mx(0), ind(-1) {}
	node_mx(int mx, int ind) : mx(mx), ind(ind) {}
};
node_mx operator+(node_mx& a, node_mx& b) {
	if (a.mx >= b.mx) {
		return node_mx(a.mx, a.ind);
	}
	return node_mx(b.mx, b.ind);
}
struct seg_tree_mx {
	int sz;
	vector<int> a;
	vector<node_mx> t;

	seg_tree_mx(vector<int>& arr) {
		sz = (int)arr.size();
		a = arr;
		t.resize(4 * sz);
		build(0, 0, sz);
	}

	void build(int v, int l, int r) {
		if (l + 1 == r) {
			t[v] = node_mx(a[l], l);
			return;
		}
		int m = (l + r) / 2;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		build(l_u, l, m);
		build(r_u, m, r);
		t[v] = t[l_u] + t[r_u];
	}

	int get(int ql, int qr) {
		return get_(0, 0, sz, ql, qr).mx;
	}
	node_mx get_(int v, int l, int r, int ql, int qr) {
		if (qr <= l || r <= ql) return node_mx();
		if (ql <= l && r <= qr) return t[v];
		int m = (l + r) / 2;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		node_mx res_l = get_(l_u, l, m, ql, qr);
		node_mx res_r = get_(r_u, m, r, ql, qr);
		return (res_l + res_r);
	}
};


struct node_num {
	int mx, mn, add;

	node_num() : mx(-1), mn(1e9), add(0) {}
	node_num(int x) : mx(x), mn(x), add(0) {}
	node_num(int mx, int mn) : mx(mx), mn(mn), add(0) {}
};
node_num operator+(node_num& a, node_num& b) {
	return node_num(max(a.mx, b.mx), min(a.mn, b.mn));
}
struct seg_tree_num {
	int sz;
	vector<node_num> t;

	seg_tree_num(int sz_) {
		sz = sz_;
		t.resize(4 * sz);
		build(0, 0, sz);
	}

	void build(int v, int l, int r) {
		if (l + 1 == r) {
			t[v] = node_num(l);
			return;
		}
		int m = (l + r) / 2;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		build(l_u, l, m);
		build(r_u, m, r);
		t[v] = t[l_u] + t[r_u];
	}

	void apply(int v, int add) {
		t[v].mx += add;
		t[v].mn += add;
		t[v].add += add;
	}
	void push(int v) {
		if (t[v].add == 0) return;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		apply(l_u, t[v].add);
		apply(r_u, t[v].add);
		t[v].add = 0;
	}

	void upd(int ql) {
		upd_(0, 0, sz, ql, sz, -1);
	}
	void upd_(int v, int l, int r, int ql, int qr, int add) {
		if (qr <= l || r <= ql) return;
		if (ql <= l && r <= qr) {
			apply(v, add);
			return;
		}
		push(v);
		int m = (l + r) / 2;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		upd_(l_u, l, m, ql, qr, add);
		upd_(r_u, m, r, ql, qr, add);
		t[v] = t[l_u] + t[r_u];
	}

	int getl(int x) {
		return getl_(0, 0, sz, x);
	}
	int getl_(int v, int l, int r, int x) {
		if (t[v].mx < x || x < t[v].mn) return -1;
		if (l + 1 == r) return l;
		push(v);
		int m = (l + r) / 2;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		int res = getl_(l_u, l, m, x);
		if (res == -1) {
			res = getl_(r_u, m, r, x);
		}
		return res;
	}

	int getr(int x) {
		return getr_(0, 0, sz, x);
	}
	int getr_(int v, int l, int r, int x) {
		if (t[v].mx < x || x < t[v].mn) return -1;
		if (l + 1 == r) return l;
		push(v);
		int m = (l + r) / 2;
		int l_u = 2 * v + 1, r_u = 2 * v + 2;
		int res = getr_(r_u, m, r, x);
		if (res == -1) {
			res = getr_(l_u, l, m, x);
		}
		return res;
	}
};


signed main() {
	cin.tie(0);
	cout.tie(0);
	cin.sync_with_stdio(0);
	cout.sync_with_stdio(0);


	int n;
	cin >> n;
	vector<int> h(n);
	for (auto& i : h) {
		cin >> i;
	}


	seg_tree_mx st_mx(h);
	seg_tree_num st_num(n);
	for (int i = 0; i < n - 1; i++) {
		int k;
		cin >> k;
		k--;
		int l1 = st_num.getl(k);
		int r1 = st_num.getr(k);
		int l2 = r1 + 1;
		int r2 = st_num.getr(k + 1);
		st_num.upd(l2);
		ll ans = 0;
		for (int j = l1; j <= r2; j++) {
			ans += min(st_mx.get(l1, j + 1), st_mx.get(j, r2 + 1)) - h[j];
		}
		cout << ans << "\n";
	}
} 