#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/tree_policy.hpp>

using namespace std;
using namespace __gnu_pbds;

using ll = long long;
using ull = unsigned long long;
using ld = long double;

#define all(v) (v).begin(), (v).end()
#define rall(v) (v).rbegin(), (v).rend()

template<typename T>
using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;

struct SegmentTree {
    int n;
    vector<ll> t;
    vector<ll> lz;

    SegmentTree(int _n) : n(_n) {
        int SIZE = (1 << (__lg(n) + bool(__builtin_popcount(n) - 1)));
        t.assign(2 * SIZE - 1, 0);
        lz.assign(2 * SIZE - 1, -1);
    }

    void push(int x, int l, int r) {
        if (lz[x] == -1) return;

        if (l + 1 != r) {
            lz[2 * x + 1] = lz[x];
            lz[2 * x + 2] = lz[x];
        }

        t[x] = (r - l) * lz[x];
        lz[x] = -1;
    }

    void update(int lq, int rq, int v, int x, int l, int r) {
        if (lq <= l && r <= rq) {
            lz[x] = v;
            push(x, l, r);
            return;
        }
        push(x, l, r);
        if (rq <= l || r <= lq) return;

        int m = (l + r) / 2;
        update(lq, rq, v, 2 * x + 1, l, m);
        update(lq, rq, v, 2 * x + 2, m, r);
        t[x] = t[2 * x + 1] + t[2 * x + 2];
    }

    void update(int lq, int rq, int v) {
        update(lq, rq, v, 0, 0, n);
    }

    ll get(int lq, int rq, int x, int l, int r) {
        push(x, l, r);
        if (lq <= l && r <= rq) return t[x];
        if (rq <= l || r <= lq) return 0;

        int m = (l + r) / 2;
        return get(lq, rq, 2 * x + 1, l, m) + get(lq, rq, 2 * x + 2, m, r);
    }

    ll get(int lq, int rq) {
        return get(lq, rq, 0, 0, n);
    }
};

struct SegmentTree_max {
    int n;
    vector<ll> t;

    void build(const vector<int>& h, int x, int l, int r) {
        if (l + 1 == r) {
            t[x] = h[l];
            return;
        }

        int m = (l + r) / 2;
        build(h, 2 * x + 1, l, m);
        build(h, 2 * x + 2, m, r);
        t[x] = max(t[2 * x + 1], t[2 * x + 2]);
    }

    SegmentTree_max(const vector<int>& h) : n(h.size()) {
        int SIZE = (1 << (__lg(n) + bool(__builtin_popcount(n) - 1)));
        t.resize(2 * SIZE - 1);
        build(h, 0, 0, n);
    }

    int find_first(int lq, int v, int x, int l, int r) {
        if (t[x] < v || r <= lq) return -1;
        if (l + 1 == r) return l;

        int m = (l + r) / 2;
        int res = find_first(lq, v, 2 * x + 1, l, m);
        if (res == -1) res = find_first(lq, v, 2 * x + 2, m, r);
        return res;
    }

    int find_first(int lq, int v) {
        return find_first(lq, v, 0, 0, n);
    }

    int find_last(int rq, int v, int x, int l, int r) {
        if (t[x] < v || rq <= l) return -1;
        if (l + 1 == r) return l;

        int m = (l + r) / 2;
        int res = find_last(rq, v, 2 * x + 2, m, r);
        if (res == -1) res = find_last(rq, v, 2 * x + 1, l, m);
        return res;
    }

    int find_last(int rq, int v) {
        return find_last(rq, v, 0, 0, n);
    }
};

struct DSU {
    int n;
    vector<int> p, l, r;
    vector<array<int, 2>> mx_l;
    vector<array<int, 2>> mx_r;

    DSU() {}
    DSU(const vector<int>& a) : n(a.size()) {
        p.resize(n);
        l.resize(n);
        r.resize(n);
        iota(all(p), 0);
        iota(all(l), 0);
        iota(all(r), 0);

        mx_l.resize(n);
        mx_r.resize(n);
        for (int i = 0; i < n; i++) {
            mx_r[i] = {a[i], i};
            mx_l[i] = {a[i], -i};
        }
    }

    int get(int a) {
        if (p[a] != a) p[a] = get(p[a]);
        return p[a];
    }

    void unite(int a, int b) {
        a = get(a);
        b = get(b);

        if (a == b) return;

        p[a] = b;
        l[b] = l[a];
        mx_l[b] = max(mx_l[a], mx_l[b]);
        mx_r[b] = max(mx_r[a], mx_r[b]);
    }
};

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin >> n;
    vector<int> h(n);
    for (int i = 0; i < n; i++) cin >> h[i];
    DSU dsu(h);

    SegmentTree ST(n);
    for (int i = 0; i < n; i++) ST.update(i, i + 1, h[i]);

    SegmentTree_max id(h);

    vector<ll> p(n);
    p[0] = h[0];
    for (int i = 1; i < n; i++) p[i] = p[i - 1] + h[i];

    auto get_sum = [&](int l, int r) -> ll {
        ll res = p[r];
        if (l != 0) res -= p[l - 1];
        return res;
    };

    ordered_set<int> now;
    for (int i = 0; i < n; i++) now.insert(i);

    for (int i = 0; i < n - 1; i++) {
        int k;
        cin >> k;
        int l = *now.find_by_order(k - 1);
        int r = *now.find_by_order(k);
        now.erase(l);
        now.erase(r);

        int mx_1 = dsu.mx_r[l][1];
        int mx_2 = -dsu.mx_l[r][1];

        if (h[mx_1] < h[mx_2]) {
            mx_2 = id.find_first(mx_1 + 1, h[mx_1]);
        } else {
            mx_1 = id.find_last(mx_2, h[mx_2]);
        }

        ST.update(mx_1 + 1, mx_2, min(h[mx_1], h[mx_2]));

        dsu.unite(l, r);
        int a = dsu.get(l);
        now.insert(a);

        cout << ST.get(dsu.l[a], dsu.r[a] + 1) - get_sum(dsu.l[a], dsu.r[a]) << '\n';
    }
}
