from functools import lru_cache


def list_to_str(l: list) -> list[str]:
    return ["|".join(map(str, sector)) for sector in l]


def str_to_list(*args) -> list:
    return [list(map(int, sector.split("|"))) for sector in args]


@lru_cache()
def get_biggest_delta(*args: str) -> int | None:
    l = str_to_list(*args)
    sums = [sum(e) for e in l]
    if len(sums) == 1:
        return
    return max(sums) - min(sums)


def get_indexes_of_element(l, element_index: int) -> (int, int):
    indexes_gone = 0
    for sector_index, sector in enumerate(l):
        if indexes_gone + len(sector) > element_index:
            return sector_index, element_index - indexes_gone
        else:
            indexes_gone += len(sector)


def cut_list(l, index: int) -> list:
    l = l.copy()

    sector_index, within_sector_index = get_indexes_of_element(l, index)
    sector = l[sector_index]

    _ = l.pop(sector_index)
    l.insert(sector_index, sector[:within_sector_index + 1])
    l.insert(sector_index + 1, sector[within_sector_index + 1:])

    return l


@lru_cache()
def get_max_delta(*args: str, needed_len: int, numbers_amount: int) -> int | None:
    numbers = str_to_list(*args)

    if len(numbers) > needed_len:
        return None

    if len(numbers) == needed_len:
        return get_biggest_delta(*list_to_str(numbers))

    variants = []
    for cut_index in range(numbers_amount):
        new_numbers = cut_list(numbers, cut_index)
        if [] in new_numbers:
            continue
        variants.append((new_numbers, get_biggest_delta(*list_to_str(new_numbers))))

    deltas = []
    for variant in variants:
        if d := get_max_delta(
                *list_to_str(variant[0]),
                needed_len=needed_len,
                numbers_amount=numbers_amount
        ):
            deltas.append(d)

    return max(deltas)


def main() -> None:
    numbers_amount, needed_len = map(int, input().split())
    numbers = [list(map(int, input().split()))]

    print(get_max_delta(*list_to_str(numbers), needed_len=needed_len, numbers_amount=numbers_amount))


if __name__ == "__main__":
    main()


# 20 10
# 3 6 4 6 12  27 6 8 2 7  18 6 8 14 19  32 7 2 8 2