#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
using namespace std;
using ll = long long;
#define all(v) (v).begin(), (v).end()

struct fenwick {

    fenwick(int n) : n(n) {
        v.resize(n);
    }

    int get(int r) {
        int s = 0;
        for (; r >= 0; r = (r & (r + 1)) - 1) s += v[r];
        return s;
    }

    void add(int r, int x) {
        for (; r < n; r = (r | (r + 1))) v[r] += x;
    }

    int n;
    vector<int> v;

};

struct segtree {

    segtree(int n) : n(n) {
        v.resize(n * 4);
        ps.resize(n * 4, -1);
    }

    ll get(int l, int r) {
        return get(l, r, 0, 0, n - 1);
    }

    void upd(int l, int r, ll x) {
        upd(l, r, x, 0, 0, n - 1);
    }

    void push(int pos, int tl, int tr) {
        if (ps[pos] == -1) return;
        int m = (tl + tr) / 2;
        v[pos * 2 + 1] = ps[pos] * (m - tl + 1);
        ps[pos * 2 + 1] = ps[pos];
        v[pos * 2 + 2] = ps[pos] * (tr - m);
        ps[pos * 2 + 2] = ps[pos];
        ps[pos] = -1;
    }

    ll get(int l, int r, int pos, int tl, int tr) {
        if (r < tl || tr < l) return 0;
        if (l <= tl && tr <= r) return v[pos];
        push(pos, tl, tr);
        int m = (tl + tr) / 2;
        return get(l, r, pos * 2 + 1, tl, m) + get(l, r, pos * 2 + 2, m + 1, tr);
    }

    void upd(int l, int r, ll x, int pos, int tl, int tr) {
        if (r < tl || tr < l) return;
        if (l <= tl && tr <= r) {
            v[pos] = x * (tr - tl + 1);
            ps[pos] = x;
            return;
        }
        int m = (tl + tr) / 2;
        push(pos, tl, tr);
        upd(l, r, x, pos * 2 + 1, tl, m);
        upd(l, r, x, pos * 2 + 2, m + 1, tr);
        v[pos] = v[pos * 2 + 1] + v[pos * 2 + 2];
    }

    int n;
    vector<ll> v, ps;

};

void solve() {
    int n;
    cin >> n;
    vector<int> h(n);
    for (int& x : h) cin >> x;

    vector<ll> prefh(n);
    for (int i = 0; i < n; i++) {
        prefh[i] = (i > 0 ? prefh[i - 1] : 0) + h[i];
    }

    fenwick f(n);
    for (int i = 0; i < n; i++) f.add(i, 1);

    auto find_k = [&](int k) {
        int l = -1, r = n;
        while (l + 1 < r) {
            int m = (l + r) / 2;
            if (f.get(m) <= k) l = m;
            else r = m;
        }
        return r;
        };

    segtree pref(n), suff(n);
    for (int i = 0; i < n; i++) {
        pref.upd(i, i, h[i]);
        suff.upd(i, i, h[i]);
    }

    for (int id = 0; id < n - 1; id++) {
        int k;
        cin >> k; k--;

        int pos1 = find_k(k), pos2 = find_k(k + 1), len1 = pos2 - pos1, len2 = find_k(k + 2) - pos2;
        f.add(pos2, -1);

        int sf = suff.get(pos2, pos2);
        if (sf > suff.get(pos2 - 1, pos2 - 1)) {
            int l = pos1 - 1, r = pos2 - 1;
            while (l + 1 < r) {
                int m = (l + r) / 2;
                if (sf > suff.get(m, m)) r = m;
                else l = m;
            }
            suff.upd(r, pos2 - 1, sf);
        }
        int pr = pref.get(pos2 - 1, pos2 - 1);
        if (pr > pref.get(pos2, pos2)) {
            int l = pos2, r = pos2 + len2;
            while (l + 1 < r) {
                int m = (l + r) / 2;
                if (pr > pref.get(m, m)) l = m;
                else r = m;
            }
            pref.upd(pos2, l, pr);
        }

        int l = pos1 - 1, r = pos2 + len2;
        while (l + 1 < r) {
            int m = (l + r) / 2;
            if (pref.get(pos1, m) <= suff.get(pos1, m)) l = m;
            else r = m;
        }

        ll res = -(prefh[pos2 + len2 - 1] - (pos1 == 0 ? 0 : prefh[pos1 - 1]));
        if (l >= pos1) res += pref.get(pos1, l);
        if (r <= pos2 + len2 - 1) res += suff.get(r, pos2 + len2 - 1);
        cout << res << "\n";
    }
}

int main() {
    cin.tie(nullptr);
    ios::sync_with_stdio(false);

    solve();
}