#include <iostream>
#include <cinttypes>
#include <vector>
#include <list>
#include <algorithm>

struct Segment
{
    uint32_t start;
    uint32_t stop;
    Segment(uint32_t single) : start{single}, stop{single + 1} {}
    Segment(uint32_t _start, uint32_t _stop) : start{_start}, stop{_stop} {}
};

Segment merge_segments(std::list<Segment> &segments, const uint32_t index)
{
    auto cur = segments.begin();
    for (uint32_t i = 0; i < index; i++)
        cur++;
    auto next = std::next(cur);
    if (next != segments.end())
    {
        cur->stop = next->stop;
        segments.erase(next);
    }
    return *cur;
}

uint32_t capacity(uint32_t const *h, const Segment seg)
{
    uint32_t sum = 0;
    for (uint32_t p = seg.start; p < seg.stop; p++)
    {
        uint32_t lp = 0;
        uint32_t rp = 0;
        for (uint32_t i = seg.start; i <= p; i++)
            lp = std::max(lp, h[i]);
        for (uint32_t i = p; i < seg.stop; i++)
            rp = std::max(rp, h[i]);
        sum += std::min(lp, rp) - h[p];
    }
    return sum;
}

int main()
{
    uint32_t n;
    std::cin >> n;
    if (n < 1)
        return 1;
    std::list<Segment> segments;
    uint32_t heights[n];
    uint32_t commands[n - 1];
    for (uint32_t i = 0; i < n; i++)
        segments.push_back(Segment(i));
    for (uint32_t i = 0; i < n; i++)
        std::cin >> heights[i];
    for (uint32_t i = 0; i < n - 1; i++)
        std::cin >> commands[i];

    for (uint32_t i = 0; i < n - 1; i++)
    {
        Segment new_seg = merge_segments(segments, commands[i] - 1);
        std::cout << capacity(heights, new_seg) << std::endl;
    }
    return 0;
}
