#include <iostream>
#include <cinttypes>
#include <vector>
#include <list>
#include <algorithm>
#include <cassert>

struct Segment
{
    int64_t start;
    int64_t stop;
    Segment(int64_t single) : start{single}, stop{single + 1} {}
    Segment(int64_t _start, int64_t _stop) : start{_start}, stop{_stop} {}
};

Segment merge_segments(std::list<Segment> &segments, const int64_t index)
{
    auto cur = segments.begin();
    for (int64_t i = 0; i < index; i++)
    {
        cur++;
        assert(cur != segments.end());
    }
    auto next = std::next(cur);
    if (next != segments.end())
    {
        cur->stop = next->stop;
        segments.erase(next);
    }
    return *cur;
}

int64_t capacity(int64_t const *h, const Segment seg)
{
    if (seg.stop - seg.start == 1)
        return 0;
    int64_t sum = 0;
    for (int64_t p = seg.start; p < seg.stop; p++)
    {
        int64_t lp = 0;
        int64_t rp = 0;
        for (int64_t i = seg.start; i <= p; i++)
            lp = std::max(lp, h[i]);
        for (int64_t i = p; i < seg.stop; i++)
            rp = std::max(rp, h[i]);
        int64_t depth = std::min(lp, rp) - h[p];
        assert(depth >= 0);
        sum += depth;
    }
    return sum;
}

int main()
{
    int64_t n;
    std::cin >> n;
    if (n < 1)
        return 1;
    std::list<Segment> segments;
    int64_t *heights = (int64_t*)malloc(sizeof(int64_t) * n);
    int64_t *commands = (int64_t*)malloc(sizeof(int64_t) * (n - 1));
    for (int64_t i = 0; i < n; i++)
        segments.push_back(Segment(i));
    for (int64_t i = 0; i < n; i++)
        std::cin >> heights[i];
    for (int64_t i = 0; i < n - 1; i++)
        std::cin >> commands[i];

    for (int64_t i = 0; i < n - 1; i++)
    {
        Segment new_seg = merge_segments(segments, commands[i] - 1);
        std::cout << capacity(heights, new_seg) << std::endl;
    }
    return 0;
}
