#include <iostream>
#include <cinttypes>
#include <vector>
#include <forward_list>
#include <algorithm>
#include <cassert>

struct Segment
{
    int64_t start;
    int64_t stop;
    Segment(int64_t single) : start{single}, stop{single + 1} {}
    Segment(int64_t _start, int64_t _stop) : start{_start}, stop{_stop} {}
};

Segment merge_segments(std::forward_list<Segment> &segments, const int64_t index)
{
    auto cur = segments.begin();
    for (int64_t i = 0; i < index; i++)
    {
        cur++;
    }
    auto next = std::next(cur);
    if (next != segments.end())
    {
        cur->stop = next->stop;
        segments.erase_after(cur);
    }
    return *cur;
}

/*
int64_t capacity(int64_t const *h, const Segment seg)
{
    if (seg.stop - seg.start <= 2)
        return 0;
    int64_t sum = 0;
    for (int64_t p = seg.start; p < seg.stop; p++)
    {
        int64_t lp = 0;
        int64_t rp = 0;
        for (int64_t i = seg.start; i <= p; i++)
            lp = lp > h[i]? lp : h[i];
        for (int64_t i = p; i < seg.stop; i++)
            rp = rp > h[i]? rp : h[i];
        int64_t depth = (lp < rp? lp : rp) - h[p];
        sum += depth;
    }
    return sum;
}*/

int64_t capacity(int64_t const *h, int64_t *pool, const Segment seg)
{
    if (seg.stop - seg.start <= 2)
        return 0;
    int64_t lp = 0;
    int64_t rp = 0;
    int64_t sum = 0;
    for (int64_t i = seg.start; i < seg.stop; i++)
    {
            lp = lp > h[i]? lp : h[i];
            pool[2*i] = lp;
    }
    for (int64_t i = seg.stop - 1; i >= 0; i--)
    {
            rp = rp > h[i]? rp : h[i];
            pool[2*i + 1] = rp;
    }
    for (int64_t p = seg.start; p < seg.stop; p++)
    {
        int64_t lp = pool[2*p];
        int64_t rp = pool[2*p + 1];
        int64_t depth = (lp < rp? lp : rp) - h[p];
        sum += depth;
    }
    return sum;
}

int main()
{
    int64_t n;
    std::cin >> n;
    if (n < 1)
        return 1;
    std::forward_list<Segment> segments;
    int64_t *heights = (int64_t*)malloc(sizeof(int64_t) * n);
    int64_t *pool = (int64_t*)malloc(sizeof(int64_t) * 2 * n);
    int64_t *commands = (int64_t*)malloc(sizeof(int64_t) * (n - 1));
    auto seg_iter = segments.before_begin();
    for (int64_t i = 0; i < n; i++)
    {
        segments.emplace_after(seg_iter, Segment(i));
        ++seg_iter;
    }
    for (int64_t i = 0; i < n; i++)
        std::cin >> heights[i];
    for (int64_t i = 0; i < n - 1; i++)
        std::cin >> commands[i];

    for (int64_t i = 0; i < n - 1; i++)
    {
        Segment new_seg = merge_segments(segments, commands[i] - 1);
        std::cout << capacity(heights, pool, new_seg) << std::endl;
    }
    free(pool);
    return 0;
}
