#include <iostream>
#include <cmath>
#include <cinttypes>
#include <vector>
#include <deque>

using namespace std;


uint64_t segments_skew(const vector<uint32_t> &numbers, const deque<size_t> &segments)
{
    size_t pos = 0;
    uint64_t min_sum = -1;
    uint64_t max_sum = 0;
    for (auto it = segments.begin(); it != segments.end(); it++)
    {
        size_t end = *it;
        if (next(it) == segments.end())
            end = numbers.size();
        uint64_t sum = 0;
        for (size_t i = pos; i < end; i++)
            sum += numbers[i];
        if (sum > max_sum)
            max_sum = sum;
        if (sum < min_sum || min_sum == -1)
            min_sum = sum;
        pos = end;
    }
    return max_sum - min_sum;
}

/*
uint64_t max_skew(const vector<uint32_t> &numbers, deque<size_t> segments, size_t k)
{
    if (segments.size() == k)
    {
        return segments_skew(numbers, segments);
    }
    if (segments.size() > k)
        return 0;
    if (segments.size() == 0)
        segments.push_back(1);
    uint64_t r1 = 0;
    size_t last_value = segments.back();
    if (numbers.size() - last_value < k - segments.size())
        return 0;
    if (numbers.size() - last_value > k - segments.size())
    {
        segments.pop_back();
        segments.push_back(last_value+1);
        r1 = max_skew(numbers, segments, k);
    }
    segments.pop_back();
    segments.push_back(last_value);
    segments.push_back(last_value+1);
    uint64_t r2 = max_skew(numbers, segments, k);
    return r1 > r2? r1 : r2;
}*/

struct State
{
    size_t k;
    const vector<uint32_t> &numbers;
    int64_t prev_min{-1};
    int64_t prev_max{-1};
    size_t cur_segment{1};
    size_t cur_position{1};
    size_t cur_sum{0};

    State(size_t _k, const vector<uint32_t> &_numbers) : k{_k}, numbers{_numbers} {}
};

void update_stats(State &s)
{
    if (s.prev_min == -1 || s.cur_sum < s.prev_min)
        s.prev_min = s.cur_sum;
    if (s.prev_max == -1 || s.cur_sum > s.prev_max)
        s.prev_max = s.cur_sum;
}

uint64_t max_skew(State &s)
{
    if (s.k == 2)
    {
        uint64_t sum_left = 0, sum_right = 0, max_diff = 0;
        for (size_t i = 0; i < s.numbers.size(); i++)
            sum_right += s.numbers[i];
        for (size_t i = 1; i < s.numbers.size(); i++)
        {
            sum_left += s.numbers[i - 1];
            sum_right -= s.numbers[i - 1];
            max_diff = max(max_diff, max(sum_left, sum_right) - min(sum_left, sum_right));
        }
        return max_diff;
    }
    if (s.cur_segment == s.k)
    {
        for (size_t &i = s.cur_position; i < s.numbers.size(); i++)
            s.cur_sum += s.numbers[i];
        update_stats(s);
        return s.prev_max - s.prev_min;
    }
    if (s.cur_segment > s.k)
        return 0;
    if (s.cur_segment == 1 && s.cur_position == 1)
    {
        s.cur_sum = s.numbers[0];
    }
    uint64_t r1 = 0, r2 = 0;
    if (s.cur_position >= s.numbers.size() || s.numbers.size() - s.cur_position < s.k - s.cur_segment)
        return 0;
    if (s.numbers.size() - s.cur_position > s.k - s.cur_segment)
    {
        State new_s = s;
        new_s.cur_sum += new_s.numbers[new_s.cur_position++];
        r1 = max_skew(new_s);
    }
    {
        State new_s = s;
        update_stats(new_s);
        new_s.cur_segment++;
        new_s.cur_sum = new_s.numbers[new_s.cur_position++];
        r2 = max_skew(new_s);
    }
    return max(r1, r2);
}

int main()
{
    size_t n, k;
    cin >> n >> k;
    vector<uint32_t> numbers(n);
    for (size_t i = 0; i < n; i++)
        cin >> numbers[i];
    //deque<size_t> segments;
    //cout << max_skew(numbers, segments, k) << endl;
    State s(k, numbers);
    cout << max_skew(s) << endl;
    return 0;
}
