#include <iostream>
#include <vector>
#include <string>
#include <cstdint>

#define int long long

using namespace std;

struct Node {
	int sum, pri;
};

struct segTree {
	vector<Node> tree;
	int size = 1;

	void build(int x, int l, int r, vector<int>& a) {
		if (r - l == 1) {
			if (l < a.size()) tree[x].sum = a[l];
			return;
		}
		int m = (r + l) / 2;
		build(2 * x + 1, l, m, a);
		build(2 * x + 2, m, r, a);
		tree[x].sum = tree[2 * x + 1].sum + tree[2 * x + 2].sum;
		return;
	}

	void init(int n, vector<int>& a) {
		while (size < n) size *= 2;
		tree.assign(2 * size - 1, { 0, -1 });
		build(0, 0, n, a);
	}

	void push(int x, int l, int r) {
		if (tree[x].pri == -1) return;
		if (r - l == 1) return;
		tree[2 * x + 1].pri = tree[x].pri;
		tree[2 * x + 2].pri = tree[x].pri;
		int m = (l + r) / 2;
		tree[2 * x + 1].sum = tree[x].pri * (m - l);
		tree[2 * x + 2].sum = tree[x].pri * (r - m);
		tree[x].pri = -1;
		return;
	}

	void add(int x, int l, int r, int val, int ql, int qr) {
		push(x, l, r);
		if (qr <= l || r <= ql) return;
		if (qr <= l && r <= ql) {
			tree[x].sum = val * (r - l);
			tree[x].pri = val;
			return;
		}
		int m = (l + r) / 2;
		add(2 * x + 1, l, m, val, ql, qr);
		add(2 * x + 2, m, r, val, ql, qr);
		tree[x].sum = tree[2 * x + 1].sum + tree[2 * x + 2].sum;
		return;
	}

	int get(int x, int l, int r, int ql, int qr) {
		push(x, l, r);
		if (r <= ql || qr <= l) return 0;
		if (ql <= l && r <= qr) return tree[x].sum;
		int m = (r + l) / 2;
		return get(2 * x + 1, l, m, ql, qr) + get(2 * x + 2, m, r, ql, qr);
	}
};

struct group {
	vector<int> tree;
	int size = 1;

	void init(int n) {
		while (size < n) size *= 2;
		tree.assign(2 * size - 1, 1);
		build(0, 0, n);
	}

	void build(int x, int l, int r) {
		if (r - l == 1) {
			return;
		}
		int m = (r + l) / 2;
		build(2 * x + 1, l, m);
		build(2 * x + 2, m, r);
		tree[x] = tree[2 * x + 1] + tree[2 * x + 2];
		return;
	}

	void invalidate(int x, int l, int r, int pos) {
		if (r - l == 1) {
			tree[x] = 0;
			return;
		}
		int m = (r + l) / 2;
		if (pos < m) invalidate(2 * x + 1, l, m, pos);
		else invalidate(2 * x + 2, m, r, pos);
		tree[x] = tree[2 * x + 1] + tree[2 * x + 2];
	}

	int get(int x, int l, int r, int k) {
		if (r - l == 1) return l;
		int m = (l + r) / 2;
		if (tree[2 * x + 1] >= k) return get(2 * x + 1, l, m, k);
		return get(2 * x + 2, m, r, k);
	}

};

struct finding {
	vector<pair<int, int>> tree;
	int size = 1;

	void build(int x, int l, int r, vector<int>& a) {
		if (r - l == 1) {
			if (l < a.size()) tree[x] = { a[l],l };
			return;
		}
		int m = (r + l) / 2;
		build(2 * x + 1, l, m, a);
		build(2 * x + 2, m, r, a);
		tree[x] = max(tree[2 * x + 1], tree[2 * x + 2]);
		return;
	}

	void init(int n, vector<int>& a) {
		while (size < n) size *= 2;
		tree.assign(2 * size - 1, {-1, -1});
		build(0, 0, n, a);
	}

	pair<int, int> get(int x, int l, int r, int ql, int qr, bool need) {
		if (r <= ql || qr <= l) return { -1, -1 };
		if (ql <= l && r <= qr) return tree[x];
		int m = (l + r) / 2;
		auto u1 = get(2 * x + 1, l, m, ql, qr, need);
		auto u2 = get(2 * x + 2, m, r, ql, qr, need);
		if (u1.first < u2.first) return u2;
		if (u1.first > u2.first) return u1;
		if (need) return u2;
		return u1;
	}

	pair<int, int> get_no_low(int x, int l, int r, int ql, int qr, int val, bool need) {
		if (r - l == 1) return { -1, l };
		int m = (r + l) / 2;
		pair <int, int> ans1 = { -1, -1 };
		if (need) {
			if (tree[2 * x + 2].first >= val && !(r <= ql || qr <= m)) ans1 = get_no_low(2 * x + 2, m, r, ql, qr, val, need);
			if (ans1.second != -1) return ans1;
			if (tree[2 * x + 1].first >= val && !(m <= ql || qr <= l)) return get_no_low(2 * x + 1, l, m, ql, qr, val, need);
			return { -1, -1 };
		}
		else {
			if (tree[2 * x + 1].first >= val && !(m <= ql || qr <= l)) return get_no_low(2 * x + 1, l, m, ql, qr, val, need);
			if (ans1.second != -1) return ans1;
			if (tree[2 * x + 2].first >= val && !(r <= ql || qr <= m)) return get_no_low(2 * x + 2, m, r, ql, qr, val, need);
			return { -1, -1 };
		}
	}
};

int32_t main()
{
	int n;
	cin >> n;
	vector<int> h(n);
	for (int i = 0; i < n; i++) cin >> h[i];
	segTree seg;
	seg.init(n, h);
	vector<int> pref(n);
	pref[0] = h[0];
	for (int i = 1; i < n; i++) pref[i] = pref[i - 1] + h[i];
	finding ff;
	ff.init(n, h);
	
	group gr;
	gr.init(n);
	vector<pair<int, int>> otr(n);
	for (int i = 0; i < n; i++) otr[i] = { i, i + 1 };
	for (int i = 0; i < n - 1; i++) {
		int id;
		cin >> id;
		id--;
		int pos1 = gr.get(0, 0, n, id + 1);
		int pos2 = gr.get(0, 0, n, id + 2);

		pair<int, int> ind1 = ff.get(0, 0, n, otr[pos1].first, otr[pos1].second, true);
		pair<int, int> ind2 = ff.get(0, 0, n, otr[pos2].first, otr[pos2].second, false);
		int val = min(ind1.first, ind2.first);
		pair<int, int> ind1 = ff.get_no_low(0, 0, n, otr[pos1].first, otr[pos1].second, val, true);
		pair<int, int> ind2 = ff.get_no_low(0, 0, n, otr[pos2].first, otr[pos2].second, val, false);
		int val = min(ind1.first, ind2.first);
		if (ind1.second != ind2.second - 1) seg.add(0, 0, n, val, ind1.second + 1, ind2.second);
		otr[pos1].second = otr[pos2].second;
		gr.invalidate(0, 0, n, pos2);
		int hh = pref[otr[pos1].second - 1];
		if (otr[pos1].first > 0) hh -= pref[otr[pos1].first - 1];
		cout << seg.get(0, 0, n, otr[pos1].first, otr[pos1].second) - hh << '\n';
	}

	return 0;
}